@@ -1,27 +1,28 @@
 package Alien::MuPDF;
-$Alien::MuPDF::VERSION = '0.004';
+$Alien::MuPDF::VERSION = '0.005';
 use strict;
 use warnings;
 
-use parent qw(Alien::Base Exporter);
-our @EXPORT_OK = qw(Inline);
+use parent qw(Alien::Base);
 use File::Spec;
 
-sub Inline {
-	return unless $_[-1] eq 'C'; # Inline's error message is good
-	my $self = __PACKAGE__->new;
-	+{
-		LIBS => $self->libs,
-		INC => $self->cflags,
-		CCFLAGSEX => "-std=c99",
-		AUTO_INCLUDE => '#include "fitz.h"',
-	};
+sub mutool_path {
+  my ($self) = @_;
+  File::Spec->catfile( $self->dist_dir , 'bin', 'mutool' );
+}
+
+sub inline_auto_include {
+	return  [ 'mupdf/fitz.h' ];
 }
 
 sub cflags {
 	my ($self) = @_;
 	my $top_include = File::Spec->catfile( $self->dist_dir, qw(include) );
-	return "-I$top_include " . $self->SUPER::cflags();
+	# We do not include $self->SUPER::cflags() because that adds too many
+	# header files to the path. In particular, it adds -Imupdf/fitz, which
+	# leads to "mupdf/fitz/math.h" being included when trying to include
+	# the C standard "math.h" header.
+	return "-I$top_include";
 }
 
 1;
@@ -36,7 +37,14 @@ Alien::MuPDF - Alien package for the MuPDF PDF rendering library
 
 =head1 VERSION
 
-version 0.004
+version 0.005
+
+=head1 METHODS
+
+=head2 mutool_path
+
+Returns a C<Str> which contains the absolute path
+to the C<mutool> binary.
 
 =head1 Inline support
 
